@@ -1,6 +1,8 @@
 /* poppler-document.cc: qt interface to poppler
  * Copyright (C) 2005, Net Integration Technologies, Inc.
- * Copyright (C) 2005, Brad Hards <bradh@frogmouth.net>
+ * Copyright (C) 2005, 2008, Brad Hards <bradh@frogmouth.net>
+ * Copyright (C) 2005-2008, Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2006-2008, Pino Toscano <pino@kde.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include "poppler-qt4.h"
@@ -26,10 +28,10 @@
 #include <PDFDoc.h>
 #include <Stream.h>
 #include <Catalog.h>
+#include <DateInfo.h>
 
 #include <QtCore/QDebug>
 #include <QtCore/QFile>
-#include <QtGui/QImage>
 #include <QtCore/QByteArray>
 
 #include "poppler-private.h"
@@ -44,7 +46,7 @@ namespace Poppler {
 	DocumentData *doc = new DocumentData(new GooString(QFile::encodeName(filePath)), 
 					     new GooString(ownerPassword.data()),
 					     new GooString(userPassword.data()));
-	return checkDocument(doc);
+	return DocumentData::checkDocument(doc);
     }
 
     Document *Document::loadFromData(const QByteArray &fileContents,
@@ -55,10 +57,10 @@ namespace Poppler {
 	DocumentData *doc = new DocumentData(fileContents,
 					     new GooString(ownerPassword.data()),
 					     new GooString(userPassword.data()));
-	return checkDocument(doc);
+	return DocumentData::checkDocument(doc);
     }
     
-    Document *Document::checkDocument(DocumentData *doc)
+    Document *DocumentData::checkDocument(DocumentData *doc)
     {
 	Document *pdoc;
 	if (doc->doc->isOk() || doc->doc->getErrorCode() == errEncrypted) {
@@ -91,7 +93,7 @@ namespace Poppler {
 
     Page *Document::page(int index) const
     {
-	return new Page(this, index);
+	return new Page(m_doc, index);
     }
 
     bool Document::isLocked() const
@@ -129,7 +131,7 @@ namespace Poppler {
 	return m_doc->locked;
     }
 
-    Document::PageMode Document::pageMode(void) const
+    Document::PageMode Document::pageMode() const
     {
 	switch (m_doc->doc->getCatalog()->getPageMode()) {
 	case Catalog::pageModeNone:
@@ -149,7 +151,7 @@ namespace Poppler {
 	}
     }
 
-    Document::PageLayout Document::pageLayout(void) const
+    Document::PageLayout Document::pageLayout() const
     {
 	switch (m_doc->doc->getCatalog()->getPageLayout()) {
 	case Catalog::pageLayoutNone:
@@ -202,6 +204,29 @@ namespace Poppler {
 	return true;
     }
 
+    QByteArray Document::fontData(const FontInfo &fi) const
+    {
+	QByteArray result;
+	if (fi.isEmbedded())
+	{
+		Object refObj, strObj;
+		refObj.initRef(fi.m_data->embRef.num, fi.m_data->embRef.gen);
+		refObj.fetch(m_doc->doc->getXRef(), &strObj);
+		refObj.free();
+		if (strObj.isStream())
+		{
+			int c;
+			strObj.streamReset();
+			while ((c = strObj.streamGetChar()) != EOF)
+			{
+				result.append((char)c);
+			}
+			strObj.streamClose();
+		}
+		strObj.free();
+	}
+	return result;
+    }
 
     /* borrowed from kpdf */
     QString Document::info( const QString & type ) const
@@ -209,54 +234,28 @@ namespace Poppler {
 	// [Albert] Code adapted from pdfinfo.cc on xpdf
 	Object info;
 	if ( m_doc->locked )
-	    return NULL;
+	    return QString();
 
 	m_doc->doc->getDocInfo( &info );
 	if ( !info.isDict() )
-	    return NULL;
+	    return QString();
 
 	QString result;
 	Object obj;
 	GooString *s1;
-	GBool isUnicode;
-	Unicode u;
-	int i;
 	Dict *infoDict = info.getDict();
 
 	if ( infoDict->lookup( type.toLatin1().data(), &obj )->isString() )
 	{
 	    s1 = obj.getString();
-	    if ( ( s1->getChar(0) & 0xff ) == 0xfe && ( s1->getChar(1) & 0xff ) == 0xff )
-	    {
-		isUnicode = gTrue;
-		i = 2;
-	    }
-	    else
-	    {
-		isUnicode = gFalse;
-		i = 0;
-	    }
-	    while ( i < obj.getString()->getLength() )
-	    {
-		if ( isUnicode )
-		{
-		    u = ( ( s1->getChar(i) & 0xff ) << 8 ) | ( s1->getChar(i+1) & 0xff );
-		    i += 2;
-		}
-		else
-		{
-		    u = s1->getChar(i) & 0xff;
-		    ++i;
-		}
-		result += unicodeToQString( &u, 1 );
-	    }
+	    result = UnicodeParsedString(s1);
 	    obj.free();
 	    info.free();
 	    return result;
 	}
 	obj.free();
 	info.free();
-	return NULL;
+	return QString();
     }
 
     QStringList Document::infoKeys() const
@@ -466,7 +465,7 @@ namespace Poppler {
 
     Document::RenderHints Document::renderHints() const
     {
-        return Document::RenderHints() & m_doc->m_hints;
+        return Document::RenderHints( m_doc->m_hints );
     }
 
     PSConverter *Document::psConverter() const
@@ -474,6 +473,11 @@ namespace Poppler {
         return new PSConverter(m_doc);
     }
 
+    PDFConverter *Document::pdfConverter() const
+    {
+        return new PDFConverter(m_doc);
+    }
+
     QString Document::metadata() const
     {
         QString result;
@@ -487,37 +491,41 @@ namespace Poppler {
         return result;
     }
 
+    bool Document::hasOptionalContent() const
+    {
+        return ( m_doc->doc->getOptContentConfig() && m_doc->doc->getOptContentConfig()->hasOCGs() );
+    }
+
+    OptContentModel *Document::optionalContentModel()
+    {
+        if (m_doc->m_optContentModel.isNull()) {
+	    m_doc->m_optContentModel = new OptContentModel(m_doc->doc->getOptContentConfig(), 0);
+	}
+        return (OptContentModel *)m_doc->m_optContentModel;
+    }
+
+    QStringList Document::scripts() const
+    {
+        Catalog *catalog = m_doc->doc->getCatalog();
+        const int numScripts = catalog->numJS();
+        QStringList scripts;
+        for (int i = 0; i < numScripts; ++i) {
+            GooString *s = catalog->getJS(i);
+            if (s) {
+                scripts.append(UnicodeParsedString(s));
+                delete s;
+            }
+        }
+        return scripts;
+    }
+
     QDateTime convertDate( char *dateString )
     {
-        int year;
-        int mon = 1;
-        int day = 1;
-        int hour = 0;
-        int min = 0;
-        int sec = 0;
-        char tz = 0x00;
-        int tzHours = 0;
-        int tzMins = 0;
-
-        if ( dateString[0] == 'D' && dateString[1] == ':' )
-            dateString += 2;
-        if ( sscanf( dateString,
-		     "%4d%2d%2d%2d%2d%2d%c%2d%*c%2d",
-		     &year, &mon, &day, &hour, &min, &sec,
-		     &tz, &tzHours, &tzMins ) > 0 ) {
-            /* Workaround for y2k bug in Distiller 3 stolen from gpdf, hoping that it won't
-             * be used after y2.2k */
-            if ( year < 1930 && strlen (dateString) > 14) {
-                int century, years_since_1900;
-                if ( sscanf( dateString, "%2d%3d%2d%2d%2d%2d%2d",
-                             &century, &years_since_1900,
-                             &mon, &day, &hour, &min, &sec) == 7 )
-                    year = century * 100 + years_since_1900;
-                else {
-                    return QDateTime();
-                }
-            }
+        int year, mon, day, hour, min, sec, tzHours, tzMins;
+        char tz;
 
+        if ( parseDateString( dateString, &year, &mon, &day, &hour, &min, &sec, &tz, &tzHours, &tzMins ) )
+        {
             QDate d( year, mon, day );
             QTime t( hour, min, sec );
             if ( d.isValid() && t.isValid() ) {
@@ -536,7 +544,7 @@ namespace Poppler {
                         qWarning("unexpected tz val");
                     }
                 }
-                return dt;
+		return dt;
             }
         }
         return QDateTime();
