@@ -1,5 +1,5 @@
 /* poppler-form.h: qt4 interface to poppler
- * Copyright (C) 2007, Pino Toscano <pino@kde.org>
+ * Copyright (C) 2007-2008, Pino Toscano <pino@kde.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@
 #include <Object.h>
 
 #include "poppler-form.h"
+#include "poppler-page-private.h"
 #include "poppler-private.h"
 #include "poppler-annotation-helper.h"
 
@@ -131,6 +132,24 @@ bool FormField::isVisible() const
   return !(m_formData->annoflags & (1 << 1));
 }
 
+Link* FormField::activationAction() const
+{
+  Object tmp;
+  Object *obj = m_formData->fm->getObj();
+  Link* action = 0;
+  if (obj->dictLookup("A", &tmp)->isDict())
+  {
+    ::LinkAction *act = ::LinkAction::parseAction(&tmp, m_formData->doc->doc->getCatalog()->getBaseURI());
+    if (act)
+    {
+      action = PageData::convertLinkActionToLink(act, m_formData->doc, QRectF());
+      delete act;
+    }
+  }
+  tmp.free();
+  return action;
+}
+
 
 FormFieldButton::FormFieldButton(DocumentData *doc, ::Page *p, ::FormWidgetButton *w)
   : FormField(*new FormFieldData(doc, p, w))
