@@ -1,6 +1,9 @@
 /* poppler-qt.h: qt interface to poppler
  * Copyright (C) 2005, Net Integration Technologies, Inc.
- * Copyright (C) 2005, Brad Hards <bradh@frogmouth.net>
+ * Copyright (C) 2005, 2007, Brad Hards <bradh@frogmouth.net>
+ * Copyright (C) 2005-2008, Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2005, Stefan Kebekus <stefan.kebekus@math.uni-koeln.de>
+ * Copyright (C) 2006-2008, Pino Toscano <pino@kde.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +17,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef __POPPLER_QT_H__
@@ -22,17 +25,18 @@
 
 #include "poppler-annotation.h"
 #include "poppler-link.h"
+#include "poppler-optcontent.h"
 #include "poppler-page-transition.h"
 
 #include <QtCore/QByteArray>
 #include <QtCore/QDateTime>
 #include <QtCore/QSet>
-#include <QtCore/QVector>
-#include <QtGui/QPixmap>
 #include <QtXml/QDomDocument>
+#include "poppler-export.h"
 
 class EmbFile;
 class Sound;
+class AnnotMovie;
 
 /**
    The %Poppler Qt4 binding.
@@ -40,6 +44,7 @@ class Sound;
 namespace Poppler {
 
     class Document;
+    class DocumentData;
 
     class PageData;
 
@@ -47,6 +52,7 @@ namespace Poppler {
 
     class TextBoxData;
 
+    class PDFConverter;
     class PSConverter;
 
     /**
@@ -58,7 +64,7 @@ namespace Poppler {
 	- a QRectF that gives a box that describes where on the page
 	the text is found.
     */
-    class TextBox {
+    class POPPLER_QT4_EXPORT TextBox {
     friend class Page;
     public:
       /**
@@ -80,13 +86,26 @@ namespace Poppler {
       /**
 	  Returns the position of the text, in point, i.e., 1/72 of
 	 an inch
+
+	 \since 0.8
       */
       QRectF boundingBox() const;
 
+      /**
+	  Returns the pointer to the next text box, if there is one.
+
+	  Otherwise, it returns a null pointer.
+      */
       TextBox *nextWord() const;
 
-      double edge(int i) const;
+      /**
+	  Returns the bounding box of the \p i -th characted of the word.
+      */
+      QRectF charBoundingBox(int i) const;
 
+      /**
+	  Returns whether there is a space character after this text box
+      */
       bool hasSpaceAfter() const;
 
     private:
@@ -101,8 +120,12 @@ namespace Poppler {
        Container class for information about a font within a PDF
        document
     */
-    class FontInfo {
+    class POPPLER_QT4_EXPORT FontInfo {
+    friend class Document;
     public:
+	/**
+	   The type of font.
+	*/
 	enum Type {
 		unknown,
 		Type1,
@@ -118,10 +141,17 @@ namespace Poppler {
 		CIDTrueTypeOT
 	};
 	
+	/// \cond PRIVATE
+	/**
+	   Create a new font information container.
+	*/
+	FontInfo();
+	
 	/**
 	   Create a new font information container.
 	*/
 	FontInfo( const FontInfoData &fid );
+	/// \endcond
 	
 	/**
 	   Copy constructor.
@@ -178,6 +208,9 @@ namespace Poppler {
 	*/
 	QString typeName() const;
 
+	/**
+	   Standard assignment operator
+	*/
 	FontInfo& operator=( const FontInfo &fi );
 
     private:
@@ -189,7 +222,7 @@ namespace Poppler {
     /**
        Container class for an embedded file with a PDF document
     */
-    class EmbeddedFile {
+    class POPPLER_QT4_EXPORT EmbeddedFile {
     public:
 	/// \cond PRIVATE
 	EmbeddedFile(EmbFile *embfile);
@@ -230,12 +263,19 @@ namespace Poppler {
 	QDateTime createDate() const;
 	
 	/**
-		The checksum of the file.
+	   The MD5 checksum of the file.
 		
-		This will return an empty QString if there is no checksum element
+	   This will return an empty QByteArray if there is no checksum element.
 	*/
 	QByteArray checksum() const;
 
+	/**
+	   The MIME type of the file, if known.
+	
+	   \since 0.8
+	*/
+	QString mimeType() const;
+
 	/**
 	   The data as a byte array
 	*/
@@ -254,9 +294,14 @@ namespace Poppler {
 
 
     /**
-       Page within a PDF document
+       \brief A page in a document.
+
+       The Page class represents a single page within a PDF document.
+
+       You cannot construct a Page directly, but you have to use the Document
+       functions that return a new Page out of an index or a label.
     */
-    class Page {
+    class POPPLER_QT4_EXPORT Page {
 	friend class Document;
     public:
 	/**
@@ -264,7 +309,14 @@ namespace Poppler {
 	*/
 	~Page();
 
-	enum Rotation { Rotate0 = 0, Rotate90 = 1, Rotate180 = 2, Rotate270 = 3 };
+	/**
+	   The type of rotation to apply for an operation
+	*/
+	enum Rotation { Rotate0 = 0,   ///< Do not rotate
+			Rotate90 = 1,  ///< Rotate 90 degrees clockwise
+			Rotate180 = 2, ///< Rotate 180 degrees
+			Rotate270 = 3  ///< Rotate 270 degrees clockwise (90 degrees counterclockwise)
+	};
 
 	/**
 	   The kinds of page actions
@@ -275,8 +327,8 @@ namespace Poppler {
 	};
 
 	/** 
-	   Render the page to a QImage using the current Document renderer
-	   (see Document::renderBackend())
+	   Render the page to a QImage using the current
+	   \link Document::renderBackend() Document renderer\endlink.
 	   
 	   If \p x = \p y = \p w = \p h = -1, the method will automatically
            compute the size of the image from the horizontal and vertical
@@ -304,14 +356,13 @@ namespace Poppler {
 	
 	   \param rotate how to rotate the page
 
-	   \note if the current Document renderer does not appear among the
-	   Document::availableRenderBackends(), the result is \em always a null QImage.
-
 	   \warning The parameter (\p x, \p y, \p w, \p h) are not
 	   well-tested. Unusual or meaningless parameters may lead to
 	   rather unexpected results.
 
 	   \returns a QImage of the page, or a null image on failure.
+
+	   \since 0.6
         */
 	QImage renderToImage(double xres=72.0, double yres=72.0, int x=-1, int y=-1, int w=-1, int h=-1, Rotation rotate = Rotate0) const;
 
@@ -324,9 +375,20 @@ namespace Poppler {
 	**/
 	QString text(const QRectF &rect) const;
 	
-	
-	enum SearchDirection { FromTop, NextResult, PreviousResult };
-	enum SearchMode { CaseSensitive, CaseInsensitive };
+	/**
+	   The starting point for a search
+	*/
+	enum SearchDirection { FromTop,        ///< Start sorting at the top of the document
+			       NextResult,     ///< Find the next result, moving "down the page"
+			       PreviousResult  ///< Find the previous result, moving "up the page"
+	};
+
+	/**
+	   The type of search to perform
+	*/
+	enum SearchMode { CaseSensitive,   ///< Case differences cause no match in searching
+			  CaseInsensitive  ///< Case differences are ignored in matching
+	};
 	
 	/**
 	   Returns true if the specified text was found.
@@ -336,6 +398,7 @@ namespace Poppler {
 	               indicates where to continue searching for
 	   \param direction in which direction do the search
 	   \param caseSensitive be case sensitive?
+	   \param rotate the rotation to apply for the search order
 	**/
 	bool search(const QString &text, QRectF &rect, SearchDirection direction, SearchMode caseSensitive, Rotation rotate = Rotate0) const;
 	
@@ -351,6 +414,9 @@ namespace Poppler {
 	   up-to-down), the QList contains the text in the proper
 	   order.
 
+	   \note The caller owns the text boxes and they should
+	         be deleted when no longer required.
+
 	   \warning This method is not tested with Asian scripts
 	*/
 	QList<TextBox*> textList(Rotation rotate = Rotate0) const;
@@ -361,7 +427,7 @@ namespace Poppler {
 	QSizeF pageSizeF() const;
 
 	/**
-	   The size of the page, in pixels
+	   \return The dimensions of the page, in points (i.e. 1/72th on an inch)
 	*/
 	QSize pageSize() const;
 
@@ -369,15 +435,18 @@ namespace Poppler {
 	  Returns the transition of this page
 
 	  \returns a pointer to a PageTransition structure that
-	  defines how transition to this page shall be performed. The
-	  PageTransition structure is owned by this page, and will
+	  defines how transition to this page shall be performed.
+
+	  \note The PageTransition structure is owned by this page, and will
 	  automatically be destroyed when this page class is
 	  destroyed.
 	**/
 	PageTransition *transition() const;
 	
 	/**
-	  Gets the page action specified, or NULL if there is no action
+	  Gets the page action specified, or NULL if there is no action.
+
+	  \since 0.6
 	**/
 	Link *action( PageAction act ) const;
 	
@@ -413,6 +482,8 @@ namespace Poppler {
 
 	/**
 	 Returns the form fields on the page
+
+	 \since 0.6
 	*/
 	QList<FormField*> formFields() const;
 
@@ -420,30 +491,68 @@ namespace Poppler {
 	 Returns the page duration. That is the time, in seconds, that the page
 	 should be displayed before the presentation automatically advances to the next page.
 	 Returns < 0 if duration is not set.
+
+	 \since 0.6
 	*/
 	double duration() const;
 	
 	/**
 	   Returns the label of the page, or a null string is the page has no label.
+
+	 \since 0.6
 	**/
 	QString label() const;
 	
     private:
 	Q_DISABLE_COPY(Page)
 
-	Page(const Document *doc, int index);
+	Page(DocumentData *doc, int index);
 	PageData *m_page;
     };
 
-    class DocumentData;
-
 /**
-   PDF document
+   \brief PDF document.
 
-   A document potentially contains multiple Pages
+   The Document class represents a PDF document: its pages, and all the global
+   properties, metadata, etc.
+
+   \section ownership Ownership of the returned objects
+
+   All the functions that returns class pointers create new object, and the
+   responsability of those is given to the callee.
+
+   The only exception is \link Poppler::Page::transition() Page::transition()\endlink.
+
+   \section document-loading Loading
+
+   To get a Document, you have to load it via the load() & loadFromData()
+   functions.
+
+   In all the functions that have passwords as arguments, they \b must be Latin1
+   encoded. If you have a password that is a UTF-8 string, you need to use
+   QString::toLatin1() (or similar) to convert the password first.
+   If you have a UTF-8 character array, consider converting it to a QString first
+   (QString::fromUtf8(), or similar) before converting to Latin1 encoding.
+
+   \section document-rendering Rendering
+
+   To render pages of a document, you have different Document functions to set
+   various options.
+
+   \subsection document-rendering-backend Backends
+
+   %Poppler offers a different backends for rendering the pages. Currently
+   there two backends (see #RenderBackend), but only the Splash engine works
+   well and has been tested.
+
+   The available rendering backends can be discovered via availableRenderBackends().
+   The current rendering backend can be changed using setRenderBackend().
+   Please note that setting a backend not listed in the available ones
+   will always result in null QImage's.
 */
-    class Document {
+    class POPPLER_QT4_EXPORT Document {
 	friend class Page;
+	friend class DocumentData;
   
     public:
 	/**
@@ -473,6 +582,8 @@ namespace Poppler {
 
 	/**
 	   The render backends available
+
+	   \since 0.6
 	*/
 	enum RenderBackend {
 	    SplashBackend,   ///< Splash backend
@@ -481,6 +592,8 @@ namespace Poppler {
 
 	/**
 	   The render hints available
+
+	   \since 0.6
 	*/
 	enum RenderHint {
 	    Antialiasing = 0x00000001,      ///< Antialiasing for graphics
@@ -492,13 +605,18 @@ namespace Poppler {
 	   Load the document from a file on disk
 
 	   \param filePath the name (and path, if required) of the file to load
+	   \param ownerPassword the Latin1-encoded owner password to use in
+	   loading the file
+	   \param userPassword the Latin1-encoded user ("open") password
+	   to use in loading the file
 
-	   \return NULL on error
+	   \return the loaded document, or NULL on error
 
-	   \warning The application owns the pointer to Document, and this should
+	   \note The caller owns the pointer to Document, and this should
 	   be deleted when no longer required.
 	
-	   \warning The returning document may be locked.
+	   \warning The returning document may be locked if a password is required
+	   to open the file, and one is not provided (as the userPassword).
 	*/
 	static Document *load(const QString & filePath,
 			      const QByteArray &ownerPassword=QByteArray(),
@@ -510,9 +628,20 @@ namespace Poppler {
 	   \param fileContents the file contents. They are copied so there is no need 
 	                       to keep the byte array around for the full life time of 
 	                       the document.
+	   \param ownerPassword the Latin1-encoded owner password to use in
+	   loading the file
+	   \param userPassword the Latin1-encoded user ("open") password
+	   to use in loading the file
 
-	   \warning The application owns the pointer to Document, and this should
+	   \return the loaded document, or NULL on error
+
+	   \note The caller owns the pointer to Document, and this should
 	   be deleted when no longer required.
+	
+	   \warning The returning document may be locked if a password is required
+	   to open the file, and one is not provided (as the userPassword).
+
+	   \since 0.6
 	*/
 	static Document *loadFromData(const QByteArray &fileContents,
 			      const QByteArray &ownerPassword=QByteArray(),
@@ -532,9 +661,9 @@ namespace Poppler {
 	   \overload
 
 
-	   The intent is that you can pass in a label like "ix" and
+	   The intent is that you can pass in a label like \c "ix" and
 	   get the page with that label (which might be in the table of
-	   contents), or pass in "1" and get the page that the user
+	   contents), or pass in \c "1" and get the page that the user
 	   expects (which might not be the first page, if there is a
 	   title page and a table of contents).
 
@@ -563,6 +692,11 @@ namespace Poppler {
 
 	/**
 	   Provide the passwords required to unlock the document
+
+	   \param ownerPassword the Latin1-encoded owner password to use in
+	   loading the file
+	   \param userPassword the Latin1-encoded user ("open") password
+	   to use in loading the file
 	*/
 	bool unlock(const QByteArray &ownerPassword, const QByteArray &userPassword);
 
@@ -585,7 +719,6 @@ QDateTime modified = m_doc->date("ModDate");
 	   - ModDate: the date of the last change in the document
 
 	   \param data the type of date that is required
-
 	*/
 	QDateTime date( const QString & data ) const;
 
@@ -718,6 +851,12 @@ QString subject = m_doc->info("Subject");
 	*/
 	bool scanForFonts( int numPages, QList<FontInfo> *fontList ) const; 
 
+	/**
+	   The font data if the font is an embedded one.
+
+	   \since 0.10
+	*/
+	QByteArray fontData(const FontInfo &font) const;
 
 	/**
 	   The documents embedded within the PDF document.
@@ -733,21 +872,38 @@ QString subject = m_doc->info("Subject");
 	bool hasEmbeddedFiles() const;
 	
 	/**
-	  Gets the TOC of the Document, it is application responsabiliy to delete
-	  it when no longer needed
+	  Gets the table of contents (TOC) of the Document.
+	
+	  The caller is responsable for the returned object.
 	
 	  In the tree the tag name is the 'screen' name of the entry. A tag can have
 	  attributes. Here follows the list of tag attributes with meaning:
 	  - Destination: A string description of the referred destination
-	  - DestinationName: A 'named reference' to the viewport that must be converted
-	       using \p linkDestination( \em destination_name )
+	  - DestinationName: A 'named reference' to the viewport
 	  - ExternalFileName: A link to a external filename
 	  - Open: A bool value that tells whether the subbranch of the item is open or not
 	
-	  Returns NULL if the Document does not have TOC
+	  Resolving the final destination for each item can be done in the following way:
+	  - first, checking for 'Destination': if not empty, then a LinkDestination
+	    can be constructed straight with it
+	  - as second step, if the 'DestinationName' is not empty, then the destination
+	    can be resolved using linkDestination()
+	
+	  Note also that if 'ExternalFileName' is not emtpy, then the destination refers
+	  to that document (and not to the current one).
+	
+	  \returns the TOC, or NULL if the Document does not have one
 	*/
 	QDomDocument *toc() const;
 	
+	/**
+	   Tries to resolve the named destination \p name.
+	
+	   \note this operation starts a search through the whole document
+	
+	   \returns a new LinkDestination object if the named destination was
+	   actually found, or NULL otherwise
+	*/
 	LinkDestination *linkDestination( const QString &name );
 	
 	/**
@@ -766,21 +922,24 @@ QString subject = m_doc->info("Subject");
 	/**
 	 Sets the backend used to render the pages.
 
-	 \note setting a rendering backend that does not appear in the
-	 availableRenderBackends() will always result in null QImage's.
-
 	 \param backend the new rendering backend
+
+	 \since 0.6
 	 */
 	void setRenderBackend( RenderBackend backend );
 	/**
 	  The currently set render backend
 
 	  The default backend is \ref SplashBackend
+
+	  \since 0.6
 	 */
 	RenderBackend renderBackend() const;
 
 	/**
 	  The available rendering backends.
+
+	  \since 0.6
 	 */
 	static QSet<RenderBackend> availableRenderBackends();
 
@@ -790,10 +949,14 @@ QString subject = m_doc->info("Subject");
 	 \note some hints may not be supported by some rendering backends.
 
 	 \param on whether the flag should be added or removed.
+
+	 \since 0.6
 	 */
 	void setRenderHint( RenderHint hint, bool on = true );
 	/**
 	  The currently set render hints.
+
+	  \since 0.6
 	 */
 	RenderHints renderHints() const;
 	
@@ -801,14 +964,60 @@ QString subject = m_doc->info("Subject");
 	  Gets a new PS converter for this document.
 
 	  The caller gets the ownership of the returned converter.
+
+	  \since 0.6
 	 */
 	PSConverter *psConverter() const;
 	
+	/**
+	  Gets a new PDF converter for this document.
+
+	  The caller gets the ownership of the returned converter.
+
+	  \since 0.8
+	 */
+	PDFConverter *pdfConverter() const;
+	
 	/**
 	  Gets the metadata stream contents
+
+	  \since 0.6
 	*/
 	QString metadata() const;
 
+	/**
+	   Test whether this document has "optional content".
+
+	   Optional content is used to optionally turn on (display)
+	   and turn off (not display) some elements of the document.
+	   The most common use of this is for layers in design
+	   applications, but it can be used for a range of things,
+	   such as not including some content in printing, and
+	   displaying content in the appropriate language.
+
+	   \since 0.8
+	*/
+	bool hasOptionalContent() const;
+
+	/**
+	   Itemviews model for optional content.
+
+	   The model is owned by the document.
+
+	   \since 0.8
+	*/
+	OptContentModel *optionalContentModel();
+
+	/**
+	   Document-level JavaScript scripts.
+
+	   Returns the list of document level JavaScript scripts to be always
+	   executed before any other script.
+
+	   \since 0.10
+	*/
+	QStringList scripts() const;
+
 	/**
 	   Destructor.
 	*/
@@ -820,10 +1029,55 @@ QString subject = m_doc->info("Subject");
 	DocumentData *m_doc;
 	
 	Document(DocumentData *dataA);
-	static Document *checkDocument(DocumentData *doc);
     };
     
-    class PSConverterData;
+    class BaseConverterPrivate;
+    class PSConverterPrivate;
+    class PDFConverterPrivate;
+    /**
+       \brief Base converter.
+
+       This is the base class for the converters.
+
+       \since 0.8
+    */
+    class POPPLER_QT4_EXPORT BaseConverter
+    {
+        friend class Document;
+        public:
+            /**
+              Destructor.
+            */
+            virtual ~BaseConverter();
+
+            /** Sets the output file name. You must set this or the output device. */
+            void setOutputFileName(const QString &outputFileName);
+
+            /**
+             * Sets the output device. You must set this or the output file name.
+             *
+             * \since 0.8
+             */
+            void setOutputDevice(QIODevice *device);
+
+            /**
+              Does the conversion.
+
+              \return whether the conversion succeeded
+            */
+            virtual bool convert() = 0;
+
+        protected:
+            /// \cond PRIVATE
+            BaseConverter(BaseConverterPrivate &dd);
+            Q_DECLARE_PRIVATE(BaseConverter)
+            BaseConverterPrivate *d_ptr;
+            /// \endcond
+
+        private:
+            Q_DISABLE_COPY(BaseConverter)
+    };
+
     /**
        Converts a PDF to PS
 
@@ -837,19 +1091,30 @@ dummy.setPageSize(myPageSize);
 width = dummy.width();
 height = dummy.height();
        \endcode
+
+       \since 0.6
     */
-    class PSConverter
+    class POPPLER_QT4_EXPORT PSConverter : public BaseConverter
     {
         friend class Document;
         public:
+            /**
+              Options for the PS export.
+
+              \since 0.10
+             */
+            enum PSOption {
+                Printing = 0x00000001,              ///< The PS is generated for priting purpouses
+                StrictMargins = 0x00000002,
+                ForceRasterization = 0x00000004
+            };
+            Q_DECLARE_FLAGS( PSOptions, PSOption )
+
             /**
               Destructor.
             */
             ~PSConverter();
 
-            /** Sets the output file name. Mandatory. */
-            void setOutputFileName(const QString &outputFileName);
-
             /** Sets the list of pages to print. Mandatory. */
             void setPageList(const QList<int> &pageList);
 
@@ -916,24 +1181,73 @@ height = dummy.height();
             void setForceRasterize(bool forceRasterize);
 
             /**
-              Does the conversion.
+              Sets the options for the PS export.
+
+              \since 0.10
+             */
+            void setPSOptions(PSOptions options);
+            /**
+              The currently set options for the PS export.
+
+              The default flags are: Printing.
+
+              \since 0.10
+             */
+            PSOptions psOptions() const;
 
-              \return whether the conversion succeeded
-            */
             bool convert();
 
         private:
+            Q_DECLARE_PRIVATE(PSConverter)
             Q_DISABLE_COPY(PSConverter)
 
             PSConverter(DocumentData *document);
+    };
 
-            PSConverterData *m_data;
+    /**
+       Converts a PDF to PDF (thus saves a copy of the document).
+
+       \since 0.8
+    */
+    class POPPLER_QT4_EXPORT PDFConverter : public BaseConverter
+    {
+        friend class Document;
+        public:
+            /**
+              Options for the PDF export.
+             */
+            enum PDFOption {
+                WithChanges = 0x00000001        ///< The changes done to the document are saved as well
+            };
+            Q_DECLARE_FLAGS( PDFOptions, PDFOption )
+
+            /**
+              Destructor.
+            */
+            virtual ~PDFConverter();
+
+            /**
+              Sets the options for the PDF export.
+             */
+            void setPDFOptions(PDFOptions options);
+            /**
+              The currently set options for the PDF export.
+             */
+            PDFOptions pdfOptions() const;
+
+            bool convert();
+
+        private:
+            Q_DECLARE_PRIVATE(PDFConverter)
+            Q_DISABLE_COPY(PDFConverter)
+
+            PDFConverter(DocumentData *document);
     };
 
     /**
        Conversion from PDF date string format to QDateTime
     */
-    QDateTime convertDate( char *dateString );
+    POPPLER_QT4_EXPORT QDateTime convertDate( char *dateString );
 
     class SoundData;
     /**
@@ -942,8 +1256,10 @@ height = dummy.height();
 	A sound can be either External (in that case should be loaded the file
        whose url is represented by url() ), or Embedded, and the player has to
        play the data contained in data().
+
+       \since 0.6
     */
-    class SoundObject {
+    class POPPLER_QT4_EXPORT SoundObject {
     public:
 	/**
 	   The type of sound
@@ -970,17 +1286,17 @@ height = dummy.height();
 	~SoundObject();
 
 	/**
-	   Is the sound embedded (\ref Embedded ) or external (\ref External )?
+	   Is the sound embedded (SoundObject::Embedded) or external (SoundObject::External)?
 	*/
 	SoundType soundType() const;
 
 	/**
-	   The URL of the sound file to be played, in case of \ref External
+	   The URL of the sound file to be played, in case of SoundObject::External
 	*/
 	QString url() const;
 
 	/**
-	   The data of the sound, in case of \ref Embedded
+	   The data of the sound, in case of SoundObject::Embedded
 	*/
 	QByteArray data() const;
 
@@ -1010,6 +1326,66 @@ height = dummy.height();
 	SoundData *m_soundData;
     };
 
+    class MovieData;
+    /**
+       Container class for a movie object in a PDF document.
+
+       \since 0.10
+    */
+    class POPPLER_QT4_EXPORT MovieObject {
+    friend class Page;
+    public:
+	/**
+	   The play mode for playing the movie
+	*/
+	enum PlayMode {
+	    PlayOnce,         ///< Play the movie once, closing the movie controls at the end
+	    PlayOpen,         ///< Like PlayOnce, but leaving the controls open
+	    PlayRepeat,       ///< Play continuously until stopped
+	    PlayPalindrome    ///< Play forward, then backward, then again foward and so on until stopped
+	};
+
+	~MovieObject();
+
+	/**
+	   The URL of the movie to be played
+	*/
+	QString url() const;
+
+	/**
+	   The size of the movie
+	*/
+	QSize size() const;
+
+	/**
+	   The rotation (either 0, 90, 180, or 270 degrees clockwise) for the movie,
+	*/
+	int rotation() const;
+
+	/**
+	   Whether show a bar with movie controls
+	*/
+	bool showControls() const;
+
+	/**
+	   How to play the movie
+	*/
+	PlayMode playMode() const;
+
+    private:
+	/// \cond PRIVATE
+	MovieObject( AnnotMovie *ann );
+	/// \endcond
+	
+	Q_DISABLE_COPY(MovieObject)
+
+	MovieData *m_movieData;
+    };
+
 }
 
+Q_DECLARE_OPERATORS_FOR_FLAGS(Poppler::Document::RenderHints)
+Q_DECLARE_OPERATORS_FOR_FLAGS(Poppler::PDFConverter::PDFOptions)
+Q_DECLARE_OPERATORS_FOR_FLAGS(Poppler::PSConverter::PSOptions)
+
 #endif
